--[[
GridAlert : Detox

Provides an audible notification when any one in the raid gains a debuff that
the player can dispell.

Note that "what the player can dispell" really means what the player's class is
expected to be able to dispell at level 60.
]]

local GridAlertDetox = GridAlert:NewModule("GridAlertDetox")
GridAlertDetox.defaultState = true
GridAlertDetox.defaultDB = {
	message = nil,
	sound_filename = "Sound\\interface\\AuctionWindowOpen.wav",
	sound_name = nil,
	min_pause = 0.5,
}

function GridAlertDetox:OnEnable()
	local core = self.core
	local name = self.name
	local c = select(2, UnitClass("player"))
	local t = core.db.profile.triggers
	if c == "MAGE" then
		t.debuff_curse.gain.any = name
		t.debuff_disease.gain.any = nil
		t.debuff_magic.gain.any = nil
		t.debuff_poison.gain.any = nil
	elseif c == "DRUID" then
		t.debuff_curse.gain.any = name
		t.debuff_disease.gain.any = nil
		t.debuff_magic.gain.any = nil
		t.debuff_poison.gain.any = name
	elseif c == "PALADIN" then
		t.debuff_curse.gain.any = nil
		t.debuff_disease.gain.any = name
		t.debuff_magic.gain.any = name
		t.debuff_poison.gain.any = name
	elseif c == "SHAMAN" then
		t.debuff_curse.gain.any = nil
		t.debuff_disease.gain.any = name
		t.debuff_magic.gain.any = nil
		t.debuff_poison.gain.any = name
	elseif c == "PRIEST" then
		t.debuff_curse.gain.any = nil
		t.debuff_disease.gain.any = name
		t.debuff_magic.gain.any = name
		t.debuff_poison.gain.any = nil
	else
		return
	end
	local p = self.db.profile
	core:SetAlertSoundOptions(name,
		p.message,
		p.sound_filename,
		p.sound_name,
		p.min_pause)
end

function GridAlertDetox:OnInitialize()
	self.super.OnInitialize(self)
end
